pub enum LegalComment {
None,
Inline,
Eof,
Linked(String),
External,
}Expand description
Legal comment
Variants
None
Do not preserve any legal comments.
Inline
Preserve all legal comments (default).
Eof
Move all legal comments to the end of the file.
Linked(String)
Return all legal comments and link then to them with a comment to the provided string.
External
Move all legal comments to a .LEGAL.txt file but to not link to them.
Implementations